/**
  ******************************************************************************
  * @file    main.c
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    11/20/2009
  * @brief   Main program body
  ******************************************************************************
  * @copy
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2009 STMicroelectronics</center></h2>
  *
  *
  * ******************************************************************
  * 23.02.2016 NR
  * Modified "STM32F107_ETH_LwIP_V1.0.0" (stsw-stm32026.zip) example from ST
  * to match Olimex STM32-P107 Rev.D board with LAN8710A PHY and CoIDE
  *
  * IDE: CoIde V1.7.8 and included (slightly outdated) cmsis V3.01 and stm_lib V3.5.0
  * Compiler: GNU Tools ARM Embedded\4.9 2015q3
  *
  * PHY: LAN8710A in RMII mode clocked by MCO from uC, IRQ handling for PHY removed
  *
  * Demo starts in webserver mode with DHCP activated.
  * Only works if LAN cable is plugged in at boot-up.
  *	- tftpserver and SD card not yet supported
  *
  *			Hints to port the ST demo to the LAN87XX PHY and other tipps:
  *			http://electrodesigns.net/blog/lwip-stm32f107/
  *			http://andybrown.me.uk/2012/09/01/ethernet-phy-stm32f107/
  *
  *			Hints on how to change the webservers websites:
  *			http://www.aimagin.com/tgr/tgr12/amgf4connect/doc/HTML/webpage_configuration.htm
  *
  */

/* Includes ------------------------------------------------------------------*/
#include "main.h"
#include "stm32_eth.h"
#include "netconf.h"
#include "helloworld.h"
#include "httpd.h"
//#include "tftpserver.h"

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
#define SYSTEMTICK_PERIOD_MS  10

/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
__IO uint32_t LocalTime = 0; /* this variable is used to create a time reference incremented by 10ms */
uint32_t timingdelay;

/* Private function prototypes -----------------------------------------------*/
void System_Periodic_Handle(void);

/* Private functions ---------------------------------------------------------*/

/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
int main(void)
{
  
  /* Setup STM32 system (clocks, Ethernet, GPIO, NVIC) and board resources */
  System_Setup();
             
  /* Initilaize the LwIP satck */
  LwIP_Init();
  
  /* Initilaize the HelloWorld module */
  HelloWorld_init();

  /* Initilaize the webserver module */
  httpd_init();

  /* Initialize the TFTP server */
  //tftpd_init();

  /* Infinite loop */
  while (1)
  {    
	/* Periodic tasks */
	System_Periodic_Handle();
  }
}

/**
  * @brief  Inserts a delay time.
  * @param  nCount: number of 10ms periods to wait for.
  * @retval None
  */
void Delay(uint32_t nCount)
{
  /* Capture the current local time */
  timingdelay = LocalTime + nCount;  

  /* wait until the desired delay finish */  
  while(timingdelay > LocalTime)
  {     
  }
}

/**
  * @brief  Updates the system local time
  * @param  None
  * @retval None
  */
void Time_Update(void)
{
  LocalTime += SYSTEMTICK_PERIOD_MS;
}

/**
  * @brief  Handles the periodic tasks of the system
  * @param  None
  * @retval None
  */
void System_Periodic_Handle(void)
{
  /* Update the LCD display and the LEDs status */
  /* Manage the IP address setting */
  //Display_Periodic_Handle(LocalTime);
  
  /* LwIP periodic services are done here */
  LwIP_Periodic_Handle(LocalTime);
}


#ifdef  USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  /* Infinite loop */
  while (1)
  {}
}
#endif


/******************* (C) COPYRIGHT 2009 STMicroelectronics *****END OF FILE****/
